"use strict";
/**
 * Copyright 2022 Synchronous Technologies Pte Ltd
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = require("fs");
const chalk_1 = __importDefault(require("chalk"));
const axios_1 = __importDefault(require("axios"));
const form_data_1 = __importDefault(require("form-data"));
const config_1 = __importDefault(require("../config"));
const compression_1 = require("../utils/compression");
const auth_1 = require("../utils/auth");
const deploy = (options) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        console.log(chalk_1.default.green("Deploying project..."));
        let uplaodQueue = [];
        const user = yield (0, auth_1.checkAuth)();
        const schemaPath = options.schema || "schema.graphql";
        if ((0, fs_1.existsSync)(schemaPath)) {
            const data = yield (0, fs_1.readFileSync)(schemaPath);
            uplaodQueue.push({
                name: "schema.graphql",
                type: "graphql",
                data: data,
            });
            console.log(chalk_1.default.green("Found file: schema.graphql"));
        }
        const hooksPath = options.hooks || "hooks.py";
        if ((0, fs_1.existsSync)(hooksPath)) {
            const data = yield (0, fs_1.readFileSync)(hooksPath);
            uplaodQueue.push({
                name: "hooks.py",
                type: "hooks",
                data: data,
            });
            console.log(chalk_1.default.green("Found file: hooks.py"));
        }
        if (uplaodQueue.length === 0) {
            console.log(chalk_1.default.red("Err: No files to upload"));
            return;
        }
        // Zip files before uploading
        const zipPath = yield (0, compression_1.zipFiles)(uplaodQueue);
        console.log(chalk_1.default.green("Zipping files"));
        // Upload files
        console.log(chalk_1.default.green("Deploying service..."));
        const form = new form_data_1.default();
        form.append("file", (0, fs_1.createReadStream)(zipPath));
        const uploadResponse = yield axios_1.default.post(`${config_1.default.host}/v1/deployment/deploy`, form, {
            headers: {
                "Content-Type": "multipart/form-data",
                // Authorization: `Bearer TODO`,
                "X-Api-Key": (user === null || user === void 0 ? void 0 : user.apiKey) || "",
            },
            timeout: 1000 * 60 * 5,
        });
        console.log(uploadResponse);
        if (uploadResponse.status === 200) {
            console.log(chalk_1.default.green("Deployment successful!"));
            console.log(chalk_1.default.green("GraphQL URL: " + uploadResponse.data.url));
        }
        else {
            throw new Error("Upload failed");
        }
    }
    catch (err) {
        console.error(chalk_1.default.red("Deployment failed"));
        console.error(chalk_1.default.red("====================================="));
        console.error(chalk_1.default.red(err));
        console.error(chalk_1.default.red("====================================="));
    }
});
exports.default = deploy;
