"use strict";
/**
 * Copyright 2022 Synchronous Technologies Pte Ltd
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = __importDefault(require("chalk"));
const axios_1 = __importDefault(require("axios"));
const config_1 = __importDefault(require("../config"));
const auth_1 = require("../utils/auth");
const list = () => __awaiter(void 0, void 0, void 0, function* () {
    const user = yield (0, auth_1.checkAuth)();
    const listResponse = yield axios_1.default.get(`${config_1.default.host}/v1/services`, {
        headers: {
            "Content-Type": "multipart/form-data",
            // Authorization: `Bearer TODO`,
            "X-Api-Key": (user === null || user === void 0 ? void 0 : user.apiKey) || "",
        },
    });
    if (listResponse.status === 200) {
        if (config_1.default.mode === "development") {
            console.log("listResponse.data", listResponse.data);
        }
        if (listResponse.data.length !== 0) {
            console.log(chalk_1.default.green(`Your services:`));
            console.log(chalk_1.default.green("=============="));
            listResponse.data.forEach((service, index) => {
                console.log(chalk_1.default.green(`Name: ${service.name}`));
                console.log(chalk_1.default.green(`Status: `) +
                    `${service.status.availableReplicas === 1
                        ? chalk_1.default.green("ready")
                        : chalk_1.default.red("not ready")}`);
                console.log(chalk_1.default.green(`Generation: ${service.generation}`));
                console.log(chalk_1.default.green(`Created at: ${service.createdAt}`));
                console.log(chalk_1.default.green(`URL: ${service.url}`));
                console.log(chalk_1.default.green("=============="));
            });
        }
        else {
            console.log(chalk_1.default.blue("No services found"));
        }
    }
    else {
        throw new Error("List failed");
    }
});
exports.default = list;
