#!/usr/bin/env node
"use strict";
/**
 * Copyright 2022 Synchronous Technologies Pte Ltd
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const commander_1 = require("commander");
const init_1 = __importDefault(require("./commands/init"));
const up_1 = __importDefault(require("./commands/up"));
const deploy_1 = __importDefault(require("./commands/deploy"));
const list_1 = __importDefault(require("./commands/list"));
const logs_1 = __importDefault(require("./commands/logs"));
const start_1 = __importDefault(require("./commands/start"));
const stop_1 = __importDefault(require("./commands/stop"));
const delete_1 = __importDefault(require("./commands/delete"));
const program = new commander_1.Command();
program.name("zefhub").description("ZefHub CLI").version("0.0.12");
const easygraphql = program.command("easygraphql");
easygraphql
    .command("init")
    .description("initialize a new project")
    .action(init_1.default);
easygraphql
    .command("deploy")
    .description("deploy project to zefhub")
    .addOption(new commander_1.Option("--schema [path]", "path to schema file").preset("schema.graphql"))
    .addOption(new commander_1.Option("--hooks [path]", "path to hooks file").preset("hooks.py"))
    .action(deploy_1.default);
easygraphql
    .command("up")
    .description("(DEPRICATED) deploy the project to zefhub")
    .action(up_1.default);
easygraphql
    .command("list")
    .description("list all services")
    .addHelpText("after", "will list all services deployed to ZefHub by the current user")
    .action(list_1.default);
easygraphql.command("logs").description("get logs for a service").action(logs_1.default);
easygraphql.command("start").description("start a service").action(start_1.default);
easygraphql.command("stop").description("stop a service").action(stop_1.default);
easygraphql.command("delete").description("delete a service").action(delete_1.default);
program.parse(process.argv);
