"use strict";
/**
 * Copyright 2022 Synchronous Technologies Pte Ltd
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.compressFile = exports.zipFiles = void 0;
const fs_1 = require("fs");
const os_1 = __importDefault(require("os"));
const path_1 = __importDefault(require("path"));
const crypto_1 = __importDefault(require("crypto"));
const zlib_1 = require("zlib");
const archiver_1 = __importDefault(require("archiver"));
const tempDir = path_1.default.join(os_1.default.tmpdir(), "zefhub");
const zipFiles = (fileBuffers) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        const dir = yield (0, fs_1.mkdtempSync)(tempDir);
        const outPath = dir + "/" + crypto_1.default.randomUUID() + ".zip";
        yield new Promise((resolve, reject) => {
            // create a file to stream archive data to.
            const output = (0, fs_1.createWriteStream)(outPath);
            const archive = (0, archiver_1.default)("zip", {
                zlib: { level: 9 }, // Sets the compression level.
            });
            // listen for all archive data to be written
            // 'close' event is fired only when a file descriptor is involved
            output.on("close", () => {
                // console.debug(archive.pointer() + " total bytes");
                resolve();
            });
            // This event is fired when the data source is drained no matter what was the data source.
            // It is not part of this library but rather from the NodeJS Stream API.
            // @see: https://nodejs.org/api/stream.html#stream_event_end
            output.on("end", () => {
                console.debug("Data has been drained");
            });
            // good practice to catch warnings (ie stat failures and other non-blocking errors)
            archive.on("warning", (err) => {
                if (err.code === "ENOENT") {
                    console.warn(err);
                }
                else {
                    // throw error
                    throw err;
                }
            });
            // good practice to catch this error explicitly
            archive.on("error", (err) => {
                throw err;
            });
            // pipe archive data to the file
            archive.pipe(output);
            // append a file from buffer
            for (let fileIndex = 0; fileIndex < fileBuffers.length; fileIndex++) {
                const fileBuffer = fileBuffers[fileIndex];
                archive.append(fileBuffer.data, { name: fileBuffer.name });
            }
            // finalize the archive (ie we are done appending files but streams have to finish yet)
            // 'close', 'end' or 'finish' may be fired right after calling this method so register to them beforehand
            archive.finalize();
        });
        return outPath;
    }
    catch (err) {
        console.error(err);
        throw err;
    }
});
exports.zipFiles = zipFiles;
const compressFile = (filePath) => {
    const stream = (0, fs_1.createReadStream)(filePath);
    stream
        .pipe((0, zlib_1.createGzip)())
        .pipe((0, fs_1.createWriteStream)(`${filePath}.gz`))
        .on("finish", () => console.log(`Successfully compressed the file at ${filePath}`));
};
exports.compressFile = compressFile;
